verticalitytools.label_vertical_moments_in_expr_with_chromatic_intervals
========================================================================

.. autofunction:: abjad.tools.verticalitytools.label_vertical_moments_in_expr_with_chromatic_intervals.label_vertical_moments_in_expr_with_chromatic_intervals
